@@ -25,7 +25,7 @@ use HTTP::BrowserDetect;
 use Net::DNS::Check;
 use Params::Validate qw( :all );
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~[  OBJECT METHODS  ]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
 
@@ -286,16 +286,16 @@ From source:
   $ tar xfz Apache2-WebApp-Plugin-Validate-0.X.X.tar.gz
   $ perl MakeFile.PL PREFIX=~/path/to/custom/dir LIB=~/path/to/custom/lib
   $ make
-  $ make test     <--- Make sure you do this before contacting me
+  $ make test
   $ make install
 
 Perl one liner using CPAN.pm:
 
-  perl -MCPAN -e 'install Apache2::WebApp::Plugin::Validate'
+  $ perl -MCPAN -e 'install Apache2::WebApp::Plugin::Validate'
 
 Use of CPAN.pm in interactive mode:
 
-  $> perl -MCPAN -e shell
+  $ perl -MCPAN -e shell
   cpan> install Apache2::WebApp::Plugin::Validate
   cpan> quit
 
